@@ -15,7 +15,11 @@ from azureml.core import (
 )
 
 from energinetml.core.backend import AbstractBackend
-from energinetml.settings import PYTHON_VERSION, PACKAGE_NAME
+from energinetml.settings import (
+    PYTHON_VERSION,
+    PACKAGE_NAME,
+    CLUSTER_IDLE_SECONDS_BEFORE_SCALEDOWN,
+)
 
 from .submitting import AzureSubmitContext
 from .training import AzureCloudTrainingContext, AzureLocalTrainingContext
@@ -124,6 +128,7 @@ class AzureBackend(AbstractBackend):
     def get_compute_clusters(self, workspace):
         """
         :param Workspace workspace:
+        :rtype: typing.List[AmlCompute]
         """
         try:
             return AmlCompute.list(workspace=workspace)
@@ -140,13 +145,6 @@ class AzureBackend(AbstractBackend):
         except azureml._common.exceptions.AzureMLException as e:
             raise self.parse_azureml_exception(e)
 
-    def get_suggested_vm_size(self, compute_type):
-        """
-        :param ComputeType compute_type:
-        :rtype: str
-        """
-        raise NotImplementedError
-
     def create_compute_cluster(self, workspace, name, vm_size, min_nodes, max_nodes,
                                vnet_resource_group_name, vnet_name, subnet_name):
         """
@@ -167,6 +165,7 @@ class AzureBackend(AbstractBackend):
             vnet_resourcegroup_name=vnet_resource_group_name,
             vnet_name=vnet_name,
             subnet_name=subnet_name,
+            idle_seconds_before_scaledown=CLUSTER_IDLE_SECONDS_BEFORE_SCALEDOWN,
         )
 
         try:
@@ -202,10 +201,10 @@ class AzureBackend(AbstractBackend):
 
         # Project requirements (from requirements.txt)
         for requirement in model.requirements:
-            cd.add_pip_package(str(requirement))
+            cd.add_pip_package(requirement.line)
 
         # Python environment
-        env = Environment(str(model.requirements.get(PACKAGE_NAME)))
+        env = Environment(model.requirements.get(PACKAGE_NAME).line)
         env.python.conda_dependencies = cd
 
         compute_config = RunConfiguration()
