@@ -11,7 +11,7 @@ from typing import Any, List, Dict
 
 from energinetml.settings import EMPTY_MODEL_TEMPLATE_DIR
 
-from .project import Project
+from .project import MachineLearningProject
 from .files import FileMatcher, temporary_folder
 from .configurable import Configurable
 from .requirements import RequirementList
@@ -74,8 +74,8 @@ class Model(Configurable):
         :rtype: Project
         """
         try:
-            return Project.from_directory(self.path)
-        except Project.NotFound:
+            return MachineLearningProject.from_directory(self.path)
+        except MachineLearningProject.NotFound:
             return None
 
     @cached_property
