@@ -29,15 +29,15 @@
 
 """
 import json
-import logging
 from enum import Enum
 from typing import List, Any
 from functools import cached_property
 from pydantic import BaseModel, create_model
+from opentelemetry import trace
+from opentelemetry.trace import SpanKind
 
-from opencensus.ext.azure.log_exporter import AzureLogHandler
 
-from energinetml.settings import APP_INSIGHT_INSTRUMENTATION_KEY
+tracer = trace.get_tracer(__name__)
 
 
 class PredictionInput(list):
@@ -45,6 +45,9 @@ class PredictionInput(list):
     TODO
     """
     def __init__(self, features, *args, **kwargs):
+        """
+        :param List[str] features:
+        """
         super(PredictionInput, self).__init__(*args, **kwargs)
         self.features = features
 
@@ -108,7 +111,7 @@ class PredictionController(object):
     """
     TODO
     """
-    def __init__(self, model, trained_model, model_version):
+    def __init__(self, model, trained_model, model_version=None):
         """
         :param energinetml.Model model:
         :param energinetml.TrainedModel trained_model:
@@ -118,22 +121,6 @@ class PredictionController(object):
         self.trained_model = trained_model
         self.model_version = model_version
 
-    @cached_property
-    def logger(self):
-        """
-        :rtype: logging.Logger
-        """
-        logger = logging.getLogger(__name__)
-
-        # Setup Azure App Insights backend (using OpenCensus) if necessary
-        if APP_INSIGHT_INSTRUMENTATION_KEY:
-            conn = 'InstrumentationKey=%s' % APP_INSIGHT_INSTRUMENTATION_KEY
-            handler = AzureLogHandler(connection_string=conn, export_interval=1.0)
-            logger.setLevel(logging.INFO)
-            logger.addHandler(handler)
-
-        return logger
-
     @property
     def identifiers(self):
         """
@@ -158,7 +145,9 @@ class PredictionController(object):
     @cached_property
     def request_model(self):
         """
-        TODO
+        Build a request model class (inherited from pydantic.BaseModel)
+        based on a specific TrainedModel instance. The resulting model
+        can be used for JSON input validation, Swagger docs etc.
         """
         PredictFeatures = create_model('PredictFeatures', **{
             feature: (Any, ...) for feature in self.features
@@ -195,12 +184,35 @@ class PredictionController(object):
         :param PredictRequest request:
         :rtype: PredictResponse
         """
-        # Resulting predictions with the same number of elements
-        # and in the same order as inputs
+        start_span = tracer.start_span(
+            name='prediction',
+            kind=SpanKind.SERVER,
+        )
+
+        with start_span as span:
+            identifiers, features, predictions = self.invoke_model(request)
+
+            span.set_attribute('model_name', self.model.name)
+            if self.model_version is not None:
+                span.set_attribute('model_version', self.model_version)
+            span.set_attribute('identifiers', json.dumps(identifiers))
+            span.set_attribute('features', json.dumps(features))
+            span.set_attribute('predictions', json.dumps(predictions))
+
+        return self.response_model(predictions=predictions)
+
+    def invoke_model(self, request):
+        """
+        :param PredictRequest request:
+        :rtype: PredictResponse
+        """
+        groups = list(request.group_input_by_identifier())
+        identifiers_ordered = [... for _ in range(len(request.inputs))]
+        features_ordered = [i for i in request.inputs]
         predictions_ordered = [... for _ in range(len(request.inputs))]
 
         # Invoke predict() for each unique identifier
-        for identifier, inputs in request.group_input_by_identifier():
+        for identifier, inputs in groups:
             indexes = [i[0] for i in inputs]
             feature_sets = [i[1] for i in inputs]
             input_data = PredictionInput(self.features, feature_sets)
@@ -211,33 +223,20 @@ class PredictionController(object):
                 input_data=input_data,
             )
 
-            # TODO Verify predict_result
+            # TODO Verify predict_result?
 
-            for index, prediction in zip(indexes, predict_result):
+            for index, features, prediction in \
+                    zip(indexes, feature_sets, predict_result):
+                identifiers_ordered[index] = identifier
+                features_ordered[index] = features
                 predictions_ordered[index] = prediction
 
         if ... in predictions_ordered:
             # TODO Raise...
             raise RuntimeError()
 
-        # Log input(s) and the resulting prediction(s)
-        for input, prediction in zip(request.inputs, predictions_ordered):
-            self.log_prediction(input, prediction)
-
-        return self.response_model(predictions=predictions_ordered)
-
-    def log_prediction(self, input, prediction):
-        """
-        Logs a single prediction specifically for Azure App Insight
-        """
-        i = input.dict()
-        if 'identifier' in i and isinstance(i['identifier'], Enum):
-            i['identifier'] = i['identifier'].value
-
-        self.logger.info('Prediction', extra={
-            'custom_dimensions': {
-                'modelVersion': json.dumps(self.model_version),
-                'input': json.dumps(i),
-                'prediction': json.dumps(prediction),
-            },
-        })
+        return (
+            identifiers_ordered,
+            features_ordered,
+            predictions_ordered,
+        )
