@@ -15,7 +15,7 @@ class WsgiWebApp(WebAppEngine):
     def serve(self, project):
         os.chdir(os.path.join(project.path, 'src'))
 
-        command = ('gunicorn', 'app:app')
+        command = ('waitress-serve', "--listen=*:8000", 'app:app')
 
         subprocess.check_call(
             command, stdout=sys.stdout, stderr=subprocess.STDOUT)
